@@ -1,7 +1,9 @@
 """
 Type annotations for workspaces-web service literal definitions.
 
-[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/literals/)
+[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workspaces_web/literals/)
+
+Copyright 2025 Vlad Emelianov
 
 Usage::
 
@@ -23,40 +25,118 @@ else:
 __all__ = (
     "AuthenticationTypeType",
     "BrowserTypeType",
+    "CategoryType",
     "EnabledTypeType",
+    "EventType",
+    "FolderStructureType",
     "IdentityProviderTypeType",
     "InstanceTypeType",
+    "ListDataProtectionSettingsPaginatorName",
+    "ListSessionLoggersPaginatorName",
     "ListSessionsPaginatorName",
+    "LogFileFormatType",
+    "MaxDisplayResolutionType",
+    "PaginatorName",
     "PortalStatusType",
+    "RedactionPlaceHolderTypeType",
+    "RegionName",
     "RendererTypeType",
+    "ResourceServiceName",
+    "ServiceName",
     "SessionSortByType",
     "SessionStatusType",
+    "ToolbarItemType",
+    "ToolbarTypeType",
+    "VisualModeType",
     "WorkSpacesWebServiceName",
-    "ServiceName",
-    "ResourceServiceName",
-    "PaginatorName",
-    "RegionName",
 )
 
 
 AuthenticationTypeType = Literal["IAM_Identity_Center", "Standard"]
 BrowserTypeType = Literal["Chrome"]
+CategoryType = Literal[
+    "Chat",
+    "CriminalActivity",
+    "Cults",
+    "DownloadSites",
+    "Gambling",
+    "Games",
+    "GenerativeAI",
+    "Hacking",
+    "HateAndIntolerance",
+    "IllegalDrug",
+    "IllegalSoftware",
+    "ImageSharing",
+    "InstantMessaging",
+    "Nudity",
+    "ParkedDomains",
+    "PeerToPeer",
+    "Pornography",
+    "ProfessionalNetwork",
+    "SchoolCheating",
+    "SelfHarm",
+    "SexEducation",
+    "SocialNetworking",
+    "StreamingMediaAndDownloads",
+    "Tasteless",
+    "Violence",
+    "Weapons",
+    "WebBasedEmail",
+]
 EnabledTypeType = Literal["Disabled", "Enabled"]
+EventType = Literal[
+    "ContentCopyFromWebsite",
+    "ContentPasteToWebsite",
+    "ContentTransferFromLocalToRemoteClipboard",
+    "FileDownloadFromSecureBrowserToRemoteDisk",
+    "FileTransferFromLocalToRemoteDisk",
+    "FileTransferFromRemoteToLocalDisk",
+    "FileUploadFromRemoteDiskToSecureBrowser",
+    "PrintJobSubmit",
+    "SessionConnect",
+    "SessionDisconnect",
+    "SessionEnd",
+    "SessionStart",
+    "TabClose",
+    "TabOpen",
+    "UrlBlockByContentFilter",
+    "UrlLoad",
+    "WebsiteInteract",
+]
+FolderStructureType = Literal["Flat", "NestedByDate"]
 IdentityProviderTypeType = Literal[
     "Facebook", "Google", "LoginWithAmazon", "OIDC", "SAML", "SignInWithApple"
 ]
 InstanceTypeType = Literal["standard.large", "standard.regular", "standard.xlarge"]
+ListDataProtectionSettingsPaginatorName = Literal["list_data_protection_settings"]
+ListSessionLoggersPaginatorName = Literal["list_session_loggers"]
 ListSessionsPaginatorName = Literal["list_sessions"]
+LogFileFormatType = Literal["JSONLines", "Json"]
+MaxDisplayResolutionType = Literal[
+    "size1024X768",
+    "size1280X720",
+    "size1920X1080",
+    "size2560X1440",
+    "size3440X1440",
+    "size3840X2160",
+    "size4096X2160",
+    "size800X600",
+]
 PortalStatusType = Literal["Active", "Incomplete", "Pending"]
+RedactionPlaceHolderTypeType = Literal["CustomText"]
 RendererTypeType = Literal["AppStream"]
 SessionSortByType = Literal["StartTimeAscending", "StartTimeDescending"]
 SessionStatusType = Literal["Active", "Terminated"]
+ToolbarItemType = Literal["DualMonitor", "FullScreen", "Microphone", "Webcam", "Windows"]
+ToolbarTypeType = Literal["Docked", "Floating"]
+VisualModeType = Literal["Dark", "Light"]
 WorkSpacesWebServiceName = Literal["workspaces-web"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
     "acm",
     "acm-pca",
+    "aiops",
     "amp",
     "amplify",
     "amplifybackend",
@@ -77,7 +157,7 @@ ServiceName = Literal[
     "apprunner",
     "appstream",
     "appsync",
-    "apptest",
+    "arc-region-switch",
     "arc-zonal-shift",
     "artifact",
     "athena",
@@ -87,12 +167,21 @@ ServiceName = Literal[
     "b2bi",
     "backup",
     "backup-gateway",
+    "backupsearch",
     "batch",
+    "bcm-dashboards",
     "bcm-data-exports",
+    "bcm-pricing-calculator",
+    "bcm-recommended-actions",
     "bedrock",
     "bedrock-agent",
     "bedrock-agent-runtime",
+    "bedrock-agentcore",
+    "bedrock-agentcore-control",
+    "bedrock-data-automation",
+    "bedrock-data-automation-runtime",
     "bedrock-runtime",
+    "billing",
     "billingconductor",
     "braket",
     "budgets",
@@ -141,6 +230,7 @@ ServiceName = Literal[
     "connect",
     "connect-contact-lens",
     "connectcampaigns",
+    "connectcampaignsv2",
     "connectcases",
     "connectparticipant",
     "controlcatalog",
@@ -167,6 +257,7 @@ ServiceName = Literal[
     "drs",
     "ds",
     "ds-data",
+    "dsql",
     "dynamodb",
     "dynamodbstreams",
     "ebs",
@@ -178,7 +269,6 @@ ServiceName = Literal[
     "efs",
     "eks",
     "eks-auth",
-    "elastic-inference",
     "elasticache",
     "elasticbeanstalk",
     "elastictranscoder",
@@ -191,6 +281,7 @@ ServiceName = Literal[
     "es",
     "events",
     "evidently",
+    "evs",
     "finspace",
     "finspace-data",
     "firehose",
@@ -202,6 +293,10 @@ ServiceName = Literal[
     "freetier",
     "fsx",
     "gamelift",
+    "gameliftstreams",
+    "geo-maps",
+    "geo-places",
+    "geo-routes",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -220,16 +315,15 @@ ServiceName = Literal[
     "inspector-scan",
     "inspector2",
     "internetmonitor",
+    "invoicing",
     "iot",
     "iot-data",
     "iot-jobs-data",
-    "iot1click-devices",
-    "iot1click-projects",
+    "iot-managed-integrations",
     "iotanalytics",
     "iotdeviceadvisor",
     "iotevents",
     "iotevents-data",
-    "iotfleethub",
     "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
@@ -244,6 +338,7 @@ ServiceName = Literal[
     "kendra",
     "kendra-ranking",
     "keyspaces",
+    "keyspacesstreams",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -267,8 +362,6 @@ ServiceName = Literal[
     "location",
     "logs",
     "lookoutequipment",
-    "lookoutmetrics",
-    "lookoutvision",
     "m2",
     "machinelearning",
     "macie2",
@@ -279,6 +372,7 @@ ServiceName = Literal[
     "marketplace-catalog",
     "marketplace-deployment",
     "marketplace-entitlement",
+    "marketplace-reporting",
     "marketplacecommerceanalytics",
     "mediaconnect",
     "mediaconvert",
@@ -298,6 +392,7 @@ ServiceName = Literal[
     "migrationhub-config",
     "migrationhuborchestrator",
     "migrationhubstrategy",
+    "mpa",
     "mq",
     "mturk",
     "mwaa",
@@ -305,19 +400,22 @@ ServiceName = Literal[
     "neptune-graph",
     "neptunedata",
     "network-firewall",
+    "networkflowmonitor",
     "networkmanager",
     "networkmonitor",
-    "nimble",
+    "notifications",
+    "notificationscontacts",
     "oam",
+    "observabilityadmin",
+    "odb",
     "omics",
     "opensearch",
     "opensearchserverless",
-    "opsworks",
-    "opsworkscm",
     "organizations",
     "osis",
     "outposts",
     "panorama",
+    "partnercentral-selling",
     "payment-cryptography",
     "payment-cryptography-data",
     "pca-connector-ad",
@@ -334,13 +432,10 @@ ServiceName = Literal[
     "pipes",
     "polly",
     "pricing",
-    "privatenetworks",
     "proton",
     "qapps",
     "qbusiness",
     "qconnect",
-    "qldb",
-    "qldb-session",
     "quicksight",
     "ram",
     "rbin",
@@ -355,7 +450,6 @@ ServiceName = Literal[
     "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
-    "robomaker",
     "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
@@ -364,10 +458,13 @@ ServiceName = Literal[
     "route53domains",
     "route53profiles",
     "route53resolver",
+    "rtbfabric",
     "rum",
     "s3",
     "s3control",
     "s3outposts",
+    "s3tables",
+    "s3vectors",
     "sagemaker",
     "sagemaker-a2i-runtime",
     "sagemaker-edge",
@@ -380,6 +477,7 @@ ServiceName = Literal[
     "schemas",
     "sdb",
     "secretsmanager",
+    "security-ir",
     "securityhub",
     "securitylake",
     "serverlessrepo",
@@ -392,14 +490,14 @@ ServiceName = Literal[
     "shield",
     "signer",
     "simspaceweaver",
-    "sms",
-    "sms-voice",
     "snow-device-management",
     "snowball",
     "sns",
+    "socialmessaging",
     "sqs",
     "ssm",
     "ssm-contacts",
+    "ssm-guiconnect",
     "ssm-incidents",
     "ssm-quicksetup",
     "ssm-sap",
@@ -433,27 +531,18 @@ ServiceName = Literal[
     "wellarchitected",
     "wisdom",
     "workdocs",
-    "worklink",
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-instances",
     "workspaces-thin-client",
     "workspaces-web",
     "xray",
 ]
 ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
+    "cloudformation", "cloudwatch", "dynamodb", "ec2", "glacier", "iam", "s3", "sns", "sqs"
 ]
-PaginatorName = Literal["list_sessions"]
+PaginatorName = Literal["list_data_protection_settings", "list_session_loggers", "list_sessions"]
 RegionName = Literal[
     "ap-northeast-1",
     "ap-south-1",
